==> MetaMax-1.7.4.tar.gz: MetaMax/action.updatemeta.php <==
<?php
if (!isset($gCms)) exit;

if (! $this->CheckPermission('Use MetaMax')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

$this->SetPreference('page_smarty', $params['page_smarty']);
$this->SetPreference('page_title', $params['page_title']);
$this->SetPreference('delimiter_title', $params['delimiter_title']);
$this->SetPreference('meta_block_title', $params['meta_block_title']);
$this->SetPreference('content_var_title', $params['content_var_title']);
$this->SetPreference('block_title', $params['block_title']);
$this->SetPreference('auto_title',
		     (isset($params['auto_title'])?'1':'0'));
$this->SetPreference('length_title', $params['length_title']);

$this->SetPreference('base_title',
		     (isset($params['base_title'])?'1':'0'));
$this->SetPreference('standard_title',
		     (isset($params['standard_title'])?'1':'0'));
$this->SetPreference('dublin_title',
		     (isset($params['dublin_title'])?'1':'0'));
$this->SetPreference('opengraph_title',
		     (isset($params['opengraph_title'])?'1':'0'));

$this->SetPreference('publisher_title', $params['publisher_title']);
$this->SetPreference('contributor_title', $params['contributor_title']);
$this->SetPreference('relation_title', $params['relation_title']);
$this->SetPreference('location_title', $params['location_title']);
$this->SetPreference('region_title', $params['region_title']);
$this->SetPreference('latitude_title', $params['latitude_title']);
$this->SetPreference('longitude_title', $params['longitude_title']);
$this->SetPreference('ogtype_title', $params['ogtype_title']);
$this->SetPreference('ogimage_title', $params['ogimage_title']);
$this->SetPreference('fbadmin_title', $params['fbadmin_title']);
$this->SetPreference('fbapp_title', $params['fbapp_title']);

$params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'meta');
$this->Redirect($id, 'defaultadmin', '', $params);
?>

==> MetaMax-1.7.4.3.tar.gz: MetaMax/action.updatemeta.php <==
<?php
if (!isset($gCms)) exit;

if (! $this->CheckPermission('Use MetaMax')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

$this->SetPreference('page_smarty', $params['page_smarty']);
$this->SetPreference('page_title', $params['page_title']);
$this->SetPreference('delimiter_title', $params['delimiter_title']);
$this->SetPreference('meta_block_title', $params['meta_block_title']);
$this->SetPreference('content_var_title', $params['content_var_title']);
$this->SetPreference('block_title', $params['block_title']);
$this->SetPreference('auto_title',
		     (isset($params['auto_title'])?'1':'0'));
$this->SetPreference('length_title', $params['length_title']);

$this->SetPreference('base_title',
		     (isset($params['base_title'])?'1':'0'));
$this->SetPreference('standard_title',
		     (isset($params['standard_title'])?'1':'0'));
$this->SetPreference('dublin_title',
		     (isset($params['dublin_title'])?'1':'0'));
$this->SetPreference('opengraph_title',
		     (isset($params['opengraph_title'])?'1':'0'));

$this->SetPreference('fullscreen_title', $params['fullscreen_title']);
$this->SetPreference('statusbar_title', $params['statusbar_title']);
$this->SetPreference('phoneno_title', $params['phoneno_title']);
$this->SetPreference('width_title', $params['width_title']);
$this->SetPreference('height_title', $params['height_title']);
$this->SetPreference('initial_title', $params['initial_title']);
$this->SetPreference('minimum_title', $params['minimum_title']);
$this->SetPreference('maximum_title', $params['maximum_title']);
$this->SetPreference('scalable_title', $params['scalable_title']);

$this->SetPreference('publisher_title', $params['publisher_title']);
$this->SetPreference('contributor_title', $params['contributor_title']);
$this->SetPreference('relation_title', $params['relation_title']);
$this->SetPreference('location_title', $params['location_title']);
$this->SetPreference('region_title', $params['region_title']);
$this->SetPreference('latitude_title', $params['latitude_title']);
$this->SetPreference('longitude_title', $params['longitude_title']);
$this->SetPreference('ogtype_title', $params['ogtype_title']);
$this->SetPreference('ogimage_title', $params['ogimage_title']);
$this->SetPreference('fbadmin_title', $params['fbadmin_title']);
$this->SetPreference('fbapp_title', $params['fbapp_title']);

$params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'meta');
$this->Redirect($id, 'defaultadmin', '', $params);
?>
